@@ -89,10 +89,11 @@ class StreamModifier:
                 gw = GroupWriter(self.group_tag, self.group_index)
                 gw.write_port(443)
                 sw = StreamWriter(self.group_tag, self.group_index, sType)
-            password = input(_("please input trojan user password: "))
+            random_pass = ''.join(random.sample(string.digits + string.ascii_letters, 8))
+            tip = _("create random trojan user password:") + ColorStr.cyan(random_pass) + _(", enter to use or input new password: ")
+            password = input(tip)
             if password == "":
-                print(_("password is null!!"))
-                exit(-1)
+                password = random_pass
             kw['password'] = password
         sw.write(**kw)
 
